<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE xsl:stylesheet SYSTEM "Documentation Report.dtd">
<xsl:stylesheet version="2.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fn="http://www.w3.org/2005/xpath-functions"
	xmlns:saxon="http://saxon.sf.net/">
	<xsl:param name="contextName" />
	<xsl:param name="title" select="$documentationReport.title" />

	<xsl:output name="escaped" method="xml"
		omit-xml-declaration="yes" indent="yes" saxon:indent-spaces="2"
		saxon:line-length="40" />

	<!-- externalisations -->
	<xsl:variable name="documentationReport.title">
		<xsl:text>&documentationReport.title;</xsl:text>
	</xsl:variable>
	<xsl:variable name="documentationReport.expectedResponse">
		<xsl:text>&documentationReport.expectedResponse;</xsl:text>
	</xsl:variable>
	<xsl:variable name="documentationReport.expectedRequest">
		<xsl:text>&documentationReport.expectedRequest;</xsl:text>
	</xsl:variable>

	<xsl:template match="/">
		<html>
			<head>
				<title>
					<xsl:value-of select="$title" />
				</title>
				<link rel="stylesheet" type="text/css" href="resourcestyle.css" />
				<link rel="stylesheet" type="text/css" href="iprocessstyles.css" />
			</head>
			<body>
				<a name="top" />
				<xsl:variable name="results"
					select="document(TestSuite/task/@logLocation)/Test/summary" />

				<xsl:for-each select="$results/..">
					<xsl:apply-templates select="." />
				</xsl:for-each>
			</body>
		</html>
	</xsl:template>

	<xsl:template match="Test">

		<xsl:variable name="nameOnly" select="@testPath" />
		<!-- write a header for the test name, using path at the moment. Does this
			need to just the name -->
		<!-- <h1><xsl:value-of select="@testPath" /></h1> -->
		<h1>
			<xsl:call-template name="substring-after-last">
				<xsl:with-param name="input" select="$nameOnly" />
				<xsl:with-param name="marker" select="'/'" />
			</xsl:call-template>
		</h1>

		<!-- iterate over all children of execute. These are actions -->
		<xsl:for-each
			select="execute/comment|execute/sendRequest|execute/receiveReply|execute/publish|execute/subscribe|execute/receiveRequest|execute/sendReply">
			<!-- call apply temples for each child. This should invoke the appropiate
				template below -->
			<xsl:apply-templates select="." />
		</xsl:for-each>
	</xsl:template>

	<!-- Template for transforming the comment action xml. matches <comment> -->
	<!-- writes each comment as a paragraph. -->
	<xsl:template match="comment">
		<p>
			<xsl:value-of select="loggingMessage/text()" />
		</p>
	</xsl:template>

	<!-- Template for transforming the sendRequest action xml. matches <sendRequest> -->
	<xsl:template match="sendRequest">

		<h2>
			<xsl:value-of select="$documentationReport.expectedRequest" />
		</h2>

		<pre>
			<xsl:value-of
				select="saxon:serialize(saxon:parse(a3Message/message[2]/messageField/@value), 'escaped')" />
		</pre>
	</xsl:template>

	<!-- Template for transforming the receiveReply action xml. matches <receiveReply> -->
	<xsl:template match="receiveReply">

		<h2>
			<xsl:value-of select="$documentationReport.expectedResponse" />
		</h2>

		<pre>
			<xsl:value-of
				select="saxon:serialize(saxon:parse(a3Message/message[2]/messageField/@value), 'escaped')" />
		</pre>
	</xsl:template>

	<!-- Template for transforming the subscribe action xml. matches <subscribe> -->
	<xsl:template match="subscribe">

		<h2>
			<xsl:value-of select="$documentationReport.expectedResponse" />
		</h2>

		<pre>
			<xsl:value-of
				select="saxon:serialize(saxon:parse(a3Message/message[2]/messageField/@value), 'escaped')" />
		</pre>
	</xsl:template>

	<!-- Template for transforming the publish action xml. matches <publish> -->
	<xsl:template match="publish">

		<h2>
			<xsl:value-of select="$documentationReport.expectedRequest" />
		</h2>

		<pre>
			<xsl:value-of
				select="saxon:serialize(saxon:parse(a3Message/message[2]/messageField/@value), 'escaped')" />
		</pre>
	</xsl:template>

	<!-- Template for transforming the sendReply action xml. matches <sendReply> -->
	<xsl:template match="sendReply">

		<h2>
			<xsl:value-of select="$documentationReport.expectedRequest" />
		</h2>

		<pre>
			<xsl:value-of
				select="saxon:serialize(saxon:parse(a3Message/message[2]/messageField/@value), 'escaped')" />
		</pre>
	</xsl:template>

	<!-- Template for transforming the receiveRequest action xml. matches <receiveRequest> -->
	<xsl:template match="receiveRequest">

		<h2>
			<xsl:value-of select="$documentationReport.expectedResponse" />
		</h2>

		<pre>
			<xsl:value-of
				select="saxon:serialize(saxon:parse(a3Message/message[2]/messageField/@value), 'escaped')" />
		</pre>
	</xsl:template>

	<!-- Gets the last occurance of a delimited string. ex: input=a/b/c marker=/
		would return c -->
	<xsl:template name="substring-after-last">
		<xsl:param name="input" />
		<xsl:param name="marker" />

		<xsl:choose>
			<xsl:when test="contains($input,$marker)">
				<xsl:call-template name="substring-after-last">
					<xsl:with-param name="input"
						select="substring-after($input,$marker)" />
					<xsl:with-param name="marker" select="$marker" />
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$input" />
			</xsl:otherwise>
		</xsl:choose>

	</xsl:template>

</xsl:stylesheet>