--
-- Migrate database from schema version 1.9.24.c to 1.9.24.d
--
DROP PROCEDURE IF EXISTS update_gh_schema;

DELIMITER //
CREATE PROCEDURE update_gh_schema()
BEGIN
  DECLARE current_version varchar(100);
  SET @required_version = '1.9.24.c';

  SELECT value INTO current_version FROM db_details WHERE 
         property='schema.version.number' AND 
         ctime = (
            SELECT MAX(ctime) FROM db_details WHERE property='schema.version.number'
         );
  IF @required_version != current_version THEN
     SET @version_error = CONCAT( 'Incorrect schema version: ', current_version,
                                  ' expected: ', @required_version );
     SELECT @version_error;
  ELSE

--
-- The update script
--

ALTER TABLE 
    suite_execution
ADD 
    expiration BIGINT NULL
;

ALTER TABLE 
    suite_execution
ADD INDEX 
    suite_execution_exp_index (expiration)
;


INSERT INTO db_details VALUES
   ( now(), 'schema.version.number','1.9.24.d');

commit;

  END IF; -- Schema version check
END
//
DELIMITER ;

CALL update_gh_schema();

DROP PROCEDURE update_gh_schema;

